pub enum Decision {
NoAction,
CreateStaffTask {
location_id: LocationId,
sku: Sku,
reason: Reason,
gate: ReviewGate,
},
ManagerReviewRequired {
reason: Reason,
gate: ReviewGate,
},
VendorManagedNotice {
sku: Sku,
reason: Reason,
},
}Expand description
Reorder decision produced when available units are at or below threshold.
Variants
NoAction
No action retail operational signal for inventory, POS, reorder, recommendation, or review handling.
CreateStaffTask
Create staff task retail operational signal for inventory, POS, reorder, recommendation, or review handling.
Fields

location_id: LocationIdSource-derived location id carried by this retail contract.

gate: ReviewGateSource-derived gate carried by this retail contract.
ManagerReviewRequired
Manager review required retail operational signal for inventory, POS, reorder, recommendation, or review handling.
Fields

gate: ReviewGateSource-derived gate carried by this retail contract.
VendorManagedNotice
Vendor managed notice retail operational signal for inventory, POS, reorder, recommendation, or review handling.