Policy

Enum Policy 

pub enum Policy {
    ManualReview,
    AutoCreateManagerTask,
    VendorManaged,
}
Reorder policy deciding whether low stock creates a manager review, staff task, or vendor notice.

Variants



ManualReview

Manual review retail operational signal for inventory, POS, reorder, recommendation, or review handling.



AutoCreateManagerTask

Auto create manager task retail operational signal for inventory, POS, reorder, recommendation, or review handling.



VendorManaged

Vendor managed retail operational signal for inventory, POS, reorder, recommendation, or review handling.

Implementations

Source

impl Policy

pub fn evaluate(&self, position: &Position) -> Decision

Evaluates an inventory position against the policy and emits only threshold-backed reorder actions.