pub enum Reason {
AtOrBelowThreshold,
VendorBackorder,
ForecastedBoardingDietDepletion,
}Expand description
Business reason explaining why reorder action or vendor notice is needed.
Variants
AtOrBelowThreshold
At or below threshold retail operational signal for inventory, POS, reorder, recommendation, or review handling.
VendorBackorder
Vendor backorder retail operational signal for inventory, POS, reorder, recommendation, or review handling.
ForecastedBoardingDietDepletion
Forecasted boarding diet depletion retail operational signal for inventory, POS, reorder, recommendation, or review handling.